#include <stdio.h>
#include <stdbool.h>

#define MAX_KL 1000
#define C_WALL '#'
#define C_FREE '.'
#define WALL -1
#define FREE -2

#define FOR(i, from, to) for(i=(from); i<(to); i++)
#define FORDOWN(i, from, to) for(i=(from-1); i>=(to); i--)
#define AT(i, j) ( ((i)>=0 && (i)<K && (j)>=0 && (j)<L) ? map[i][j] : WALL )
#define MIN(a, b) ((a) < (b) ? (a) : (b))
#define MAX(a, b) ((a) > (b) ? (a) : (b))

int K, L; // size of whole area
int M, N; // size of the rectangle to erase
int map[MAX_KL][MAX_KL];

int N_areas = 0;

// number of fields in each area
int total[MAX_KL * MAX_KL];
int now[MAX_KL * MAX_KL]; 
int nonzero = 0;

int stack[MAX_KL*MAX_KL][2];
int N_stack = 0;

void stack_add(int i, int j)
{
	stack[N_stack][0] = i;
	stack[N_stack++][1] = j;
}
bool stack_pop(int *i, int *j)
{
	if(N_stack==0) return false;
	*i = stack[--N_stack][0];
	*j = stack[N_stack][1];
	return true;
}

void search(int i, int y)
{
	map[i][y] = N_areas;
	total[N_areas]++;

	if(AT(i-1, y) == FREE)
		stack_add(i-1, y);
	if(AT(i+1, y) == FREE)
		stack_add(i+1, y);
	if(AT(i, y-1) == FREE)
		stack_add(i, y-1);
	if(AT(i, y+1) == FREE)
		stack_add(i, y+1);
}

void inc(int area)
{
	if(area < 0) return;
	if(now[area]++ == 0)
		nonzero++;
}

void dec(int area)
{
	if(area < 0) return;
	if(--now[area] == 0)
		nonzero--;
}

void shift_first()
{
	// areas in the first rectange are counted manually
	// M+1, N+1: we need to check fields coming out of the rectangle
	int i, j;
	FOR(i, 0, MIN(M+1, K))
		FOR(j, 0, MIN(N+1, L))
		{
			if(i==M && j==N) continue;
			inc(AT(i, j));
		}
}

void shift_right(int I, int J)
{
	int i;
	FOR(i, I-1, MIN(I+M+1, K))
		if(i==I-1 || i==I+M)
		{
			dec(AT(i, J-1));
			inc(AT(i, J+N-1));
		}
		else
		{
			dec(AT(i, J-2));
			inc(AT(i, J+N));
		}
}

void shift_left(int I, int J)
{
	int i;
	FOR(i, I-1, MIN(I+M+1, K))
		if(i==I-1 || i==I+M)
		{
			dec(AT(i, J+N));
			inc(AT(i, J));
		}
		else
		{
			dec(AT(i, J+N+1));
			inc(AT(i, J-1));
		}
}

void shift_down(int I, int J)
{
	int j;
	FOR(j, J-1, MIN(J+N+1, L))
		if(j==J-1 || j==J+N)
		{
			dec(AT(I-1, j));
			inc(AT(I+M-1, j));
		}
		else
		{
			dec(AT(I-2, j));
			inc(AT(I+M, j));
		}
}

int main(void)
{
	int i, j;

	scanf("%d %d %d %d", &K, &L, &M, &N);
	bool reverse = (M > N);

	getchar(); // newline
	FOR(i, 0, K)
	{
		FOR(j, 0, L)
		{
			char in = (getchar()==C_WALL) ? WALL : FREE;
			if(!reverse)
				map[i][j] = in;
			else
				map[j][i] = in;
		}
		(void) getchar(); // newline
	}
	if(reverse)
	{
		int tmp = K;
		K = L;
		L = tmp;

		tmp = M;
		M = N;
		N = tmp;
	}

	FOR(i, 0, K)
		FOR(j, 0, L)
			if(AT(i, j) == FREE)
			{
				stack_add(i, j);
				int ii, jj;
				while(stack_pop(&ii, &jj))
					search(ii, jj);
				now[N_areas] = 0;
				N_areas++;
			}

	int max = 0;
	int I, J;
	
	FOR(I, 0, MAX(K-M+1, 1))
	{
		if(I % 2 == 0)
		{
			FOR(J, 0, MAX(L-N+1, 1))
			{
				if(J==0)
					if(I==0)
						shift_first();
					else
						shift_down(I, J);
				else 
					shift_right(I, J);
				if(nonzero > max)
					max = nonzero;
			}
		}
		else
		{
			FORDOWN(J, MAX(L-N+1, 1), 0)
			{
				if(J==MAX(L-N+1, 1)-1)
					shift_down(I, J);
				else
					shift_left(I, J);
				if(nonzero > max)
					max = nonzero;
			}
		}
	}
		
	printf("%d\n", max);
	return 0;
}
